# SQLAlchemy 0.7 Documentation

Search:
Release: 0.7.10 | Release Date: February 7, 2013

# SQLAlchemy Documentation

## Getting Started

A high level view and getting set up.

Overview | Installation Guide | Migration from 0.6 | Changelog catalog

## SQLAlchemy ORM

Here, the Object Relational Mapper is introduced and fully described. If you want to work with higher-level SQL which is constructed automatically for you, as well as automated persistence of Python objects, proceed first to the tutorial.

- Read this first: Object Relational Tutorial
- ORM Configuration: Mapper Configuration | Relationship Configuration | Inheritance Mapping | Advanced Collection Configuration
- Configuration Extensions: Declarative Extension | Association Proxy | Hybrid Attributes | Mutable Scalars | Ordered List
- ORM Usage: Session Usage and Guidelines | Query API reference | Relationship Loading Techniques
- Extending the ORM: ORM Event Interfaces | Internals API
- Other: Introduction to Examples | Deprecated Event Interfaces | ORM Exceptions | Horizontal Sharding | SQLSoup

## SQLAlchemy Core

The breadth of SQLAlchemy’s SQL rendering engine, DBAPI integration, transaction integration, and schema description services are documented here. In contrast to the ORM’s domain-centric mode of usage, the SQL Expression Language provides a schema-centric usage paradigm.

- Read this first: SQL Expression Language Tutorial
- All the Built In SQL: SQL Expression API
- Engines, Connections, Pools: Engine Configuration | Connections, Transactions | Connection Pooling
- Schema Definition: Tables and Columns | Database Introspection (Reflection) | Insert/Update Defaults | Constraints and Indexes | Using Data Definition Language (DDL)
- Datatypes: Overview | Generic Types | SQL Standard Types | Vendor Specific Types | Building Custom Types | API
- Extending the Core: SQLAlchemy Events | Core Event Interfaces | Creating Custom SQL Constructs | Internals API
- Other: Serializing Expressions | Deprecated Event Interfaces | Core Exceptions

## Dialect Documentation

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPIs and databases. This section describes notes, options, and usage patterns regarding individual dialects.

Drizzle | Firebird | Informix | MaxDB | Microsoft Access | Microsoft SQL Server | MySQL | Oracle | PostgreSQL | SQLite | Sybase